# ©2024, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.

from enum import Enum
from typing import Optional

from pydantic import BaseModel, Field, field_serializer
from typing_extensions import TypedDict

from ansys.solutions.oscillator_calibration.datamodel.osl.models import OslProjectInformation, OslProjectState


class ActorAndHid(TypedDict):
    actor_uid: str
    hid: Optional[str]


class ProjectInformation(BaseModel):
    """Project information to be displayed on the Project Summary page"""

    state: OslProjectState = Field(default=OslProjectState.not_started, title="State")
    id: Optional[str] = Field(default=None, title="Id")
    name: Optional[str] = Field(default=None, title="Name")
    machine: Optional[str] = Field(default=None, title="Machine")
    location: Optional[str] = Field(default=None, title="Location")
    project_directory: Optional[str] = Field(default=None, title="Project directory")
    owner: Optional[str] = Field(default=None, title="Owner")

    @field_serializer("state", return_type=str)
    def serialize_state(self, state: OslProjectState):
        return state.value

    @classmethod
    def from_osl_project_information(cls, osl_project_information: OslProjectInformation):
        return ProjectInformation(
            state=osl_project_information.state,
            id=osl_project_information.project_id,
            name=osl_project_information.name,
            machine=osl_project_information.machine,
            location=osl_project_information.location,
            project_directory=osl_project_information.working_dir,
            owner=osl_project_information.user,
        )

    def to_dict_by_title(self):
        custom_dict = {}
        default_dict = self.model_dump()
        for name, value in default_dict.items():
            custom_name = self.model_fields[name].title
            if custom_name:
                custom_dict[custom_name] = value
            else:
                custom_dict[name] = value

        return custom_dict


class AlertLevel(Enum):
    INFO = 1
    WARNING = 2
    ERROR = 3


class Alert(BaseModel):
    """Alert to be displayed in the alerts view"""

    time: float = 0.0
    origin: str = ""
    message: str = ""
    level: AlertLevel = AlertLevel.INFO
