# ©2023, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.

from typing import Any, Union

from ansys.optislang.core import Optislang
from ansys.saf.glow.solution import ProductInstanceManager, FileGroupReference, FileReference
from ansys.solutions.oscillator_calibration.solution.internal_optislang_manager_impl import (
    InternalOptislangManagerImpl, OptislangWrapperClient
)


class OptislangManager(
    ProductInstanceManager[OptislangWrapperClient], instance_manager_impl_type=InternalOptislangManagerImpl
):
    def __init__(self, **kwargs: Any):
        super().__init__(**kwargs)

    def initialize(self,
        project_path: FileReference,
        project_properties_file: FileReference,
        input_files: FileGroupReference,
        osl_version: int,
        loglevel: str,
    ):
        """Initialize and start an optiSLang product instance.

        Parameters
        ----------
        project_path : FileReference
            Optislang .opf file
        project_properties_file : FileReference, str
            Optislang placeholders file, typically called working_properties_file.json
        input_files : FileGroupReference
            File group that may contain input files required by Optislang
        osl_version : int
            The custom product version of the optiSLang instance. The format is 3 decimal digits. Example: 241
        loglevel : str
            oSL Logging level. Example: INFO
        """
        super().start(project_path, project_properties_file, input_files, osl_version, loglevel)
