# ©2022, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.

import logging
from logging import Logger
from typing import Any, Callable, Optional, Tuple, TypeVar, Union

from retrying import retry

from ansys.solutions.oscillator_calibration.utilities.common_functions import milliseconds, print_wait

T = TypeVar("T")


@retry(wait_fixed=milliseconds(seconds=2), stop_max_attempt_number=3, wait_func=print_wait)
def _attempt_unreliable(request: Callable[..., T], logger: Logger, *args: Any, **kwargs) -> T:

    logger.debug(f"Sending request {request.__name__}.")

    response = request(*args, **kwargs)

    logger.debug(f"Request {request.__name__} successful.")

    return response


def _do_nothing(e: Exception):
    pass


def attempt_unreliable_action(
    action: Callable[..., T],
    on_error: Optional[Callable[[Exception], None]],
    logger: Optional[Logger],
    *args: Any,
    **kwargs,
) -> Tuple[bool, Union[None, T]]:
    """Attempt the given action a number of times before giving up."""

    if not logger:
        logger = logging.getLogger(__name__)

    if not on_error:
        on_error = _do_nothing

    try:
        response = _attempt_unreliable(action, logger, *args, **kwargs)
        success = True
    except Exception as e:
        on_error(e)
        response = None
        success = False
    return success, response
