# ©2023, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.

"""Application."""

import dash_uploader as du
import os
import tempfile

from dash_extensions.enrich import DashProxy, MultiplexerTransform, NoOutputTransform, TriggerTransform

from ansys.solutions.oscillator_calibration.utilities.deployment import is_containerized


class Dash(DashProxy):
    """Custom Dash class."""
    def interpolate_index(self, **kwargs):

        # Get the original index content (including default Dash CSS styles) from the parent class
        index_str = super().interpolate_index(**kwargs)

        # Combine the original index content and your custom CSS
        modified_index = index_str.replace('</html>', f'<html class="light">')

        return modified_index

if is_containerized():
    # Export the solution name from the ENV variables to be used as the path prefix in dash
    path_prefix = os.environ.get("SOLUTION_NAME")
    app = Dash(
        __name__,
        suppress_callback_exceptions=True,
        transforms=[NoOutputTransform(), TriggerTransform(), MultiplexerTransform()],
        requests_pathname_prefix=f"/{path_prefix}/",
        routes_pathname_prefix=f"/{path_prefix}/",
    )
else:
    app = Dash(
        __name__,
        suppress_callback_exceptions=True,
        transforms=[NoOutputTransform(), TriggerTransform(), MultiplexerTransform()],
    )

app.css.config.serve_locally = True
app.scripts.config.serve_locally = True

# If folder doesn't exist, it will be created later
UPLOAD_DIRECTORY = os.path.join(tempfile.gettempdir(), "GLOW")
du.configure_upload(app, UPLOAD_DIRECTORY)

# !IMPORTANT Keeping the import line here to adapt with dash_uploader config, moving the import above will fail the
# dash uploader configuration
from ansys.solutions.oscillator_calibration.ui.pages.page import layout

app.layout = layout
