# ©2024, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.

from enum import Enum
from typing import Optional, Union

from dash_extensions.enrich import html

from ansys.solutions.oscillator_calibration.ui.utils.colors import ColorFilter
from ansys.solutions.oscillator_calibration.utilities.deployment import is_containerized, prepend_subdomain


class Icon(Enum):
    PLAY = "play-solid.svg"
    ROOT_NODE = "account_tree.svg"
    RESET = "backward-fast-solid.svg"
    STOP = "hand-solid.svg"
    ABORT = "stop-solid.svg"
    SHUTDOWN = "power-off-solid.svg"
    DOWNLOAD = "file-export-solid.svg"
    SYSTEM = "workspaces_filled.svg"
    NODE = "workspaces_outline.svg"
    SETTINGS = "sliders-solid.svg"

    def path(self) -> str:
        icon_path = f"/assets/icons/{self.value}"
        if is_containerized():
            return prepend_subdomain(icon_path)

        return icon_path

    def to_dash_image(
        self,
        height: Union[int, str, float, None] = None,
        color: Optional[ColorFilter] = None,
        align_center: bool = False,
    ) -> html.Img:
        style = {"display": "inline-block"}
        if height:
            style["height"] = height
        if align_center:
            style["alignItems"] = "center"

        if color:
            return html.Img(src=self.path(), style=style, className=color.value)
        else:
            return html.Img(src=self.path(), style=style)
