# ©2023, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.

import time

from ansys.saf.glow.client.dashclient import DashClient, callback
from dash_extensions.enrich import Input, State, dcc, html

from ansys.solutions.oscillator_calibration.solution.definition import Oscillator_CalibrationSolution
from ansys.solutions.oscillator_calibration.utilities.common_functions import (
    milliseconds,
    start_transaction_method_if_not_running,
)

DEFAULT_INTERVAL_SECONDS = 30.0
WAIT_INTERVAL = 1.0
MAX_WAIT_TIME = DEFAULT_INTERVAL_SECONDS - 2 * WAIT_INTERVAL


def layout() -> html.Div:
    timer = dcc.Interval(
        id="transactions_check_interval",
        interval=milliseconds(seconds=DEFAULT_INTERVAL_SECONDS),
        disabled=False,
    )
    return html.Div(
        [
            timer,
        ]
    )


@callback(
    Input("transactions_check_interval", "n_intervals"),
    State("url", "pathname"),
)
def check_and_start_data_query_transaction_methods(
    n_intervals,
    pathname,
):
    project = DashClient[Oscillator_CalibrationSolution].get_project(pathname)
    problem_setup_step = project.steps.problem_setup_step
    wait_time = 0.0
    while not problem_setup_step.osl_instance_started and wait_time < MAX_WAIT_TIME:
        time.sleep(1)
        wait_time += WAIT_INTERVAL

    if not problem_setup_step.osl_instance_started:
        return

    monitoring_step = project.steps.monitoring_step

    start_transaction_method_if_not_running(
        monitoring_step, "update_server_and_project_state", monitoring_step.update_server_and_project_state
    )

    if monitoring_step.server_healthy:
        start_transaction_method_if_not_running(monitoring_step, "update_data", monitoring_step.update_data)
        start_transaction_method_if_not_running(
            monitoring_step, "update_full_project_information", monitoring_step.update_full_project_information
        )

    return
