# ©2023, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.

"""Frontend of the project summary step."""

from ansys.saf.glow.client.dashclient import DashClient, callback
import dash_bootstrap_components as dbc
from dash_extensions.enrich import Input, Output, State, callback_context, html

from ansys.solutions.oscillator_calibration.datamodel.shared.websocket_streams import (
    ProjectInformationEvent,
    WebsocketStreamListeners,
)
from ansys.solutions.oscillator_calibration.solution.definition import Oscillator_CalibrationSolution
from ansys.solutions.oscillator_calibration.ui.components.node_control import layout as node_control_layout
from ansys.solutions.oscillator_calibration.ui.components.project_information_table import ProjectInformationTableAIO
from ansys.solutions.oscillator_calibration.ui.utils.websockets_helpers import (
    get_value_from_websocket_event_or_step,
    prevent_event_triggered_update_if_auto_update_is_disabled,
)


def layout() -> html.Div:
    """Layout of the project summary view."""

    return html.Div(
        [
            html.Br(),
            dbc.Row([dbc.Col(html.Div(id="project_information_table"), width=12)]),
            html.Br(),
            dbc.Row(
                [
                    dbc.Col(node_control_layout, width=12),
                ]
            ),
        ]
    )


@callback(
    Output("project_information_table", "children"),
    Input(WebsocketStreamListeners.PROJECT_INFORMATION.value, "message"),
    State("url", "pathname"),
    State("activate_auto_update", "on"),
)
def update_view(project_information_event, pathname, auto_update):
    """Update design table."""
    prevent_event_triggered_update_if_auto_update_is_disabled(callback_context, auto_update)

    # Get project
    project = DashClient[Oscillator_CalibrationSolution].get_project(pathname)
    # Get monitoring step
    monitoring_step = project.steps.monitoring_step

    project_information = get_value_from_websocket_event_or_step(
        project_information_event,
        monitoring_step,
        ProjectInformationEvent,
    )

    return ProjectInformationTableAIO(project_information)
